@@ -65,4 +65,29 @@ describe Object, ".aattr_initialize" do
 
     _(example.foo).must_equal "Foo"
   end
+
+  it "does not use the same default value object across class instances" do
+    klass = Class.new do
+      aattr_initialize [:name, items: []]
+    end
+
+    data = [
+      { name: "One", items: [1, 2, 3] },
+      { name: "Two", items: [4, 5, 6] },
+    ]
+
+    results = data.each_with_object([]) do |datum, results|
+      name, items = datum.values_at(:name, :items)
+      foo = klass.new(name: name)
+
+      items.each do |n|
+        foo.items << n
+      end
+
+      results << foo
+    end
+
+    _(results.first.items).must_equal [1, 2, 3]
+    _(results.last.items).must_equal [4, 5, 6]
+  end
 end
